/*
 * *********************************************************************************************************************
 *
 *          !!
 *        .F88X
 *        X8888Y
 *      .}888888N;
 *        i888888N;        .:!              .I$WI:
 *          R888888I      .'N88~            i8}+8Y&8"l8i$8>8W~'>W8}8]KW+8IIN"8&
 *          .R888888I    .;N8888~          .X8'  "8I.!,/8"  !%NY8`"8I8~~8>,88I
 *            +888888N;  .8888888Y                                  "&&8Y.}8,
 *            ./888888N;  .R888888Y        .'}~    .>}'.`+>  i}!    "i'  +/'  .'i~  !11,.:">,  .~]!  .i}i
 *              ~888888%:  .I888888l      .]88~`1/iY88Ii+1'.R$8$8]"888888888>  Y8$  W8E  X8E  W8888'188Il}Y88$*
 *              18888888    E8888881    .]W%8$`R8X'&8%++N8i,8N%N8+l8%`  .}8N:.R$RE%N88N%N$K$R  188,FE$8%~Y88I
 *            .E888888I  .i8888888'      .:$8I;88+`E8R:/8N,.>881.`$8E/1/]N8X.Y8N`"KF&&FK!'88*."88K./$88%RN888+~
 *            8888888I  .,N888888~        ~88i"8W,!N8*.I88.}888%F,i$88"F88"  888:E8X.>88!i88>`888*.}Fl1]*}1YKi'
 *          i888888N'      I888Y          ]88;/EX*IFKFK88X  K8R  .l8W  88Y  ~88}'88E&%8W.X8N``]88!.$8K  .:W8I
 *        .i888888N;        I8Y          .&8$  .X88!  i881.:%888>I88  ;88]  +88+.';;;;:.Y88X  18N.,88l  .+88/
 *      .:R888888I
 *      .&888888I                                          Copyright (c) 2009-2020.  博锐尚格科技股份有限公司
 *        ~8888'
 *        .!88~                                                                     All rights reserved.
 *
 * *********************************************************************************************************************
 */

package com.persagy.server.controllers

import com.persagy.database.SFilter
import com.persagy.server.models.TenantCascade
import com.persagy.server.models.objects.Building
import com.persagy.server.models.requests.ZoneEquipQueryRequest
import com.persagy.server.service.TenantZoneService
import com.persagy.server.service.base.BaseDataService
import com.persagy.server.service.objects.TenantService
import com.persagy.service.SPageContext
import com.persagy.service.models.responses.SQueryResponse
import io.swagger.v3.oas.annotations.Operation
import io.swagger.v3.oas.annotations.tags.Tag
import org.springframework.beans.factory.annotation.Autowired
import org.springframework.web.bind.annotation.*

/**
 * 租户相关接口
 *
 * @author 张维新
 */
@Tag(name = "租户相关接口")
@RestController
@RequestMapping("/tenant")
class TenantController {

    /**
     * 查询租户的建筑楼层
     */
   @Operation(summary=" 查询租户的建筑楼层 ", description= "")
    @PostMapping(value = ["/tenant-building-floor"])
    fun tenantBuildingFloor(@RequestParam tenantId: String,@RequestParam objectType: String): SQueryResponse<Building> {
        return TenantService.tenantBuildingFloors(tenantId,objectType)
    } //


    @Autowired
    lateinit var tenantZoneService : TenantZoneService


    /**
     * 根据业务空间查询租户
     */
   @Operation(summary=" 查询租户的建筑楼层 ", description ="")
    @PostMapping(value = ["/zone-query"])
    fun queryTenantBySpace(@RequestBody request: ZoneEquipQueryRequest): SQueryResponse<TenantCascade> {
        val withFilterList = ArrayList<SFilter>()
        val projectId = SPageContext.getHeader("projectId").toString()
        withFilterList.add(SFilter.eq("projectId", projectId))
        if(request.zoneId.isNullOrEmpty() && request.zoneType.isNullOrEmpty()) {
            return BaseDataService.tenantService.pageQuery(request, withFilterList)
        }
        if(request.notInZone == true) {
            val tenantIdsUnderSpace = tenantZoneService.getTenantIdUnderSpace(projectId)
            if(!tenantIdsUnderSpace.isNullOrEmpty())
                withFilterList.add(SFilter.not(SFilter.inList("id", tenantIdsUnderSpace)))
            return BaseDataService.tenantService.pageQuery(request, withFilterList)
        }
        val tenantIdUnderSpace = tenantZoneService.getTenantIdUnderSpace(projectId, request.zoneType, request.zoneId)
        if(tenantIdUnderSpace.isNullOrEmpty()){
            return SQueryResponse()
        }
        withFilterList.add(SFilter.inList("id", tenantIdUnderSpace))
        return BaseDataService.tenantService.pageQuery(request, withFilterList)
    } //


} // Class TenantController